VdPlayerFeatureFlags class
Constructors
- VdPlayerFeatureFlags({bool chromeCastEnabled = true, bool airPlayEnabled = true, bool pictureInPictureEnabled = true, bool screenCaptureProtectionEnabled = false, bool qualitySelectionEnabled = true, bool subtitleSelectionEnabled = true, bool keyMomentsEnabled = true, bool thumbnailPreviewEnabled = true, bool fullscreenToggleEnabled = true, bool wakelockEnabled = true, bool audioSelectionEnabled = true})
-
const
Properties
- airPlayEnabled → bool
-
final
- audioSelectionEnabled → bool
-
final
- chromeCastEnabled → bool
-
final
- fullscreenToggleEnabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyMomentsEnabled → bool
-
final
- pictureInPictureEnabled → bool
-
final
- qualitySelectionEnabled → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenCaptureProtectionEnabled → bool
-
final
- subtitleSelectionEnabled → bool
-
final
- thumbnailPreviewEnabled → bool
-
final
- wakelockEnabled → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited